@@ -4,7 +4,7 @@
 #### Tsagris Michail 01/2016
 #### mtsagris@yahoo.gr
 ################################
-dirknn <- function(x, xnew, k = 5, ina, type = "S", mesos = TRUE, parallel = FALSE) {
+dirknn <- function(x, xnew, k = 5, ina, type = "S", mesos = TRUE, parallel = FALSE, rann = FALSE) {
   ## x is the matrix containing the data
   ## xnew is the new data
   ## k is the number of neighbours to use
@@ -25,13 +25,20 @@ dirknn <- function(x, xnew, k = 5, ina, type = "S", mesos = TRUE, parallel = FAL
     g <- matrix(0, nu, klen)
     ta <- matrix(nrow = nu, ncol = nc)
     apo <- list()
-    for (m in 1:nc) {
-	disa <- tcrossprod(x[ina == m, ], xnew)
-      ## no need to compute the acos
-      #disa[ disa >= 1 ] <- 1
-      #disa[ disa <=  -1 ] <-  -1
-      #adisa <- acos(disa)
-      apo[[ m ]] <-  -Rfast::colSort(disa)[1:max(k), , drop = FALSE]
+    if (rann) {
+      for (m in 1:nc) {
+        apo[[ m ]] <- Rfast::colSort( t( RANN::nn2(data = x[ina == m, ], query = xnew, k = max(k) )$nn.dists ) )
+        apo[[ m ]] <-  0.5 * apo [[ m ]]^2 - 1
+      }
+    } else {
+      for (m in 1:nc) {
+        disa <- tcrossprod(x[ina == m, ], xnew)
+        ## no need to compute the acos
+        #disa[ disa >= 1 ] <- 1
+        #disa[ disa <=  -1 ] <-  -1
+        #adisa <- acos(disa)
+        apo[[ m ]] <- Rfast::colSort(disa, descending = TRUE)[1:max(k), , drop = FALSE]
+      }
     }
     for (j in 1:klen) {
       for (m in 1:nc) {
@@ -43,7 +50,14 @@ dirknn <- function(x, xnew, k = 5, ina, type = "S", mesos = TRUE, parallel = FAL
     }
 
   } else {   ## if type is "S"   ## Standard algorithm
-    g <- Rfast::dirknn(xnew, x, ina, k = k, type = "C", parallel = parallel)
+    if ( rann ) {
+      klen <- length(k)
+      di <- RANN::nn2( data = x, query = xnew, k = max(k) )$nn.idx
+      g <- matrix(nrow = nu, ncol = klen)
+      m1 <- matrix(nrow = max(k), ncol = nu)
+      for ( i in 1:nu )  m1[, i] <- ina[ di[i, ] ]
+      for ( j in 1:klen ) g[, j] <- Rfast::colMaxs( Rfast::colTabulate( m1[1:k[j], ] ) )
+    } else  g <- Rfast::dirknn(xnew, x, ina, k = k, type = "C", parallel = parallel)
   }  ## end if (type == "NS")
   colnames(g) <- paste("k=", k, sep = "")
   g
