@@ -9,7 +9,7 @@ embed.perm <- function(x1, x2, B = 999) {
   Rbi <- sqrt( Rfast::rowsums(S^2) ) ## the mean resultant length of each group
   S <- Rfast::colmeans(x)
   Rbar <- sqrt( sum(S^2) )  ## the mean resultant length based on all the data
-  Ft <- (n - 2) * (p - 1) * ( sum(ni * Rbi^2) - n * Rbar^2) / ( (p - 1) * ( n - sum(ni * Rbi^2) ) )
+  Ft <- (n - 2) * ( sum(ni * Rbi^2) - n * Rbar^2) / ( n - sum(ni * Rbi^2) ) 
 
   pft <- numeric(B)
   for (i in 1:B) {
