@@ -17,6 +17,6 @@ rkent <- function(n, k, m, b) {
   m <- m / sqrt( sum(m^2) )
   a <- rotation(m0, m)
   A <- diag( c(-b, 0, b) )
-  x <- rfb(n, k, m0, A)  ## simulated values with mean direction equal to m
+  x <- Directional::rfb(n, k, m0, A)  ## simulated values with mean direction equal to m
   tcrossprod(x, a)  ## simulated values with mean direction equal to m
 }
